embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Itctrl

Struct Itctrl 

#[repr(transparent)]
pub struct Itctrl(pub u32);
Integration Mode Control Register

Tuple Fields

0: u32

Implementations

Source

impl Itctrl

pub const fn integration_mode(&self) -> bool

Allows the component to switch from functional mode to integration mode or back.

pub const fn set_integration_mode(&mut self, val: bool)

Allows the component to switch from functional mode to integration mode or back.