embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Lsr

Struct Lsr 

#[repr(transparent)]
pub struct Lsr(pub u32);
Lock Status Register

Tuple Fields

0: u32

Implementations

Source

impl Lsr

pub const fn lockexist(&self) -> bool

Indicates that a lock control mechanism exists for this device. This bit reads as 0 when read from an external debugger (paddrdbg31 = 1) since external debugger accesses are not subject to Lock Registers.

pub const fn set_lockexist(&mut self, val: bool)

Indicates that a lock control mechanism exists for this device. This bit reads as 0 when read from an external debugger (paddrdbg31 = 1) since external debugger accesses are not subject to Lock Registers.

pub const fn lockgrant(&self) -> bool

Returns the current status of the Lock. This bit reads as 0 when read from an external debugger (paddrdbg31 = 1) since external debugger accesses are not subject to Lock Registers.

pub const fn set_lockgrant(&mut self, val: bool)

Returns the current status of the Lock. This bit reads as 0 when read from an external debugger (paddrdbg31 = 1) since external debugger accesses are not subject to Lock Registers.

pub const fn locktype(&self) -> bool

Indicates if the Lock Access Register (0xFB0) is implemented as 8-bit or 32-bit

pub const fn set_locktype(&mut self, val: bool)

Indicates if the Lock Access Register (0xFB0) is implemented as 8-bit or 32-bit