embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Periphid1

Struct Periphid1 

#[repr(transparent)]
pub struct Periphid1(pub u32);
Peripheral ID1 Register

Tuple Fields

0: u32

Implementations

Source

impl Periphid1

pub const fn part_1(&self) -> u8

Bits [11:8] of the component’s part number. This is selected by the designer of the component.

pub const fn set_part_1(&mut self, val: u8)

Bits [11:8] of the component’s part number. This is selected by the designer of the component.

pub const fn des_0(&self) -> u8

Bits 3:0 of the JEDEC identity code indicating the designer of the component (along with the continuation code)

pub const fn set_des_0(&mut self, val: u8)

Bits 3:0 of the JEDEC identity code indicating the designer of the component (along with the continuation code)