embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Periphid4

Struct Periphid4 

#[repr(transparent)]
pub struct Periphid4(pub u32);
Peripheral ID4 Register

Tuple Fields

0: u32

Implementations

Source

impl Periphid4

pub const fn des_2(&self) -> u8

JEDEC continuation code indicating the designer of the component (along with the identity code)

pub const fn set_des_2(&mut self, val: u8)

JEDEC continuation code indicating the designer of the component (along with the identity code)

pub const fn size(&self) -> u8

This is a 4-bit value that indicates the total contiguous size of the memory window used by this component in powers of 2 from the standard 4KB. If a component only requires the standard 4KB then this should read as 0x0, 4KB only, for 8KB set to 0x1, 16KB == 0x2, 32KB == 0x3, and so on.

pub const fn set_size(&mut self, val: u8)

This is a 4-bit value that indicates the total contiguous size of the memory window used by this component in powers of 2 from the standard 4KB. If a component only requires the standard 4KB then this should read as 0x0, 4KB only, for 8KB set to 0x1, 16KB == 0x2, 32KB == 0x3, and so on.