embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Trg

Struct Trg 

#[repr(transparent)]
pub struct Trg(pub u32);
ETB Trigger Counter Register

Tuple Fields

0: u32

Implementations

Source

impl Trg

pub const fn trigger_counter(&self) -> u16

The counter is used as follows:Trace after - The counter is set to a large value, slightly less than the number of entries in the RAM. Trace before - The counter is set to a small value. Trace about - The counter is set to half the depth of the Trace RAM. This register must not be written to when trace capture is enabled (FtStopped=0, TraceCaptEn=1). If a write is attempted, the register is not updated. A read access is permitted with trace capture enabled.

pub const fn set_trigger_counter(&mut self, val: u16)

The counter is used as follows:Trace after - The counter is set to a large value, slightly less than the number of entries in the RAM. Trace before - The counter is set to a small value. Trace about - The counter is set to half the depth of the Trace RAM. This register must not be written to when trace capture is enabled (FtStopped=0, TraceCaptEn=1). If a write is attempted, the register is not updated. A read access is permitted with trace capture enabled.